---
title: 개발 없이도 정산 시스템 도입이 가능한가요?
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: ''
tags:
  - 파트너정산자동화
  - "\b노코드"
pgCompanies:
  - 공통
searchTags:
  - 파트너 엑셀 업로드
  - 개발 없이
  - 정산 시스템
  - 개발없이
  - 노코드
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="개발 없이도 정산 시스템 도입이 가능하고 주요 기능을 쉽게 이용할 수 있습니다.
이 글은 개발 없이 이용할 수 있는 주요 기능을 설명합니다." title="" />

### 개발 없이 어떤 기능을 이용할 수 있나요?

개발 없이도 정산 시스템의 주요 기능을 모두 이용할 수 있습니다.

- 정산 정책 관리
- 파트너 관리 (단건 / 대량으로 일괄 등록)
- 수기 정산 건 등록 (단건 / 대량으로 일괄 등록)
- 송금대행 일괄지급
- 세금계산서 역발행 (단건 / 대량으로 일괄 요청)

### 정산 정책 관리

- 정산 정책은 파트너에게 정산금을 올바르게 계산하고 매칭하기 위한 기능입니다.
- 노코드 이용 가능 기능
  - 정산 주기를 포함한 계약을 생성 / 관리
  - 추가 수수료 정책 생성 / 관리
  - 할인 정책 생성 / 관리

![](/uploads/파트너정산자동화/정산정책관리.png)

### 파트너 관리

- 파트너 관리는 정산을 받을 셀러/입점사/파트너사를 등록하고 관리하는 기능입니다. 파트너 등록 시 휴폐업 조회, 예금주 조회 등을 통해서 데이터가 유효한지 검증하는 기능 또한 제공하고 있습니다.
- 노코드 이용 가능 기능
  - 파트너 개별 등록
  - 파트너 일괄 등록 (CSV 파일로 업로드)
  - 사업자 휴폐업 조회
  - 계좌 유효성 검증을 위한 예금주 조회

![](</uploads/파트너정산자동화/파트너 일괄등록.png>)

### 수기 정산건 등록

- 주문 내역을 기반으로 한 자동 정산금 계산 기능은 개발을 통해서만 이용이 가능합니다.
- 다만 어떤 파트너에게 어떤 정산금을 지급해야 하는지 계산된 내용을 업로드하는 기능은 개발 없이 이용할 수 있습니다.
- 수기 정산건을 등록하면, 정산내역으로 쌓이기 때문에 송금대행 일괄지급 서비스를 쉽게 이용할 수 있습니다.
- 노코드 이용 가능 기능
  - 수기 정산건 개별 등록 (양수 / 음수 정산 모두 가능)
  - 수기 정산건 일괄 등록 (CSV 파일로 업로드)

![](</uploads/파트너정산자동화/수기정산 일괄등록.png>)

### 송금대행 일괄지급

- 합법적이고 안전하게 파트너에게 정산금을 지급하는 기능입니다.
- 예약 지급, 즉시 지급 모두 지원합니다.

![](</uploads/파트너정산자동화/송금대행 일괄지급.png>)

### 세금계산서 역발행

- 공급받는자가 공급자 대신 세금계산서를 작성하는 기능입니다.
- 공급받는자가 발행을 요청하면, 공급자는 이메일을 확인한 뒤 승인 혹은 거부할 수 있습니다.
- 단건 / 다건 발행 모두 지원합니다.

![](</uploads/파트너정산자동화/세금계산서 일괄등록.png>)

### 그럼 꼭 개발을 해야하는 기능은 무엇인가요?

주문 내역을 기반으로 자동으로 정산금을 계산하는 기능은 \[주문 정산 생성, 주문 취소 정산 생성] 등의 정산 상세내역과 관련한 API를 개발해야 합니다.

포트원 파트너 정산 자동화 서비스가 제공하는 API를 제공하는 기능은 아래와 같습니다.

- 정책 관련 API (정책 생성, 조회, 보관, 복원 등)
- 파트너 관련 API (파트너 생성, 조회, 보관, 복원 등)
- 정산 상세내역 관련 API (주문 정산 생성, 주문 취소 정산 생성, 수기 정산 생성, 정산 건 조회, 정산 건 삭제 등)
- 계좌 관련 API (예금주 조회)
- 정산 내역 관련 API (정산 내역 다건 조회)
- 지급 내역 관련 API (지급 내역 다건 조회)
- 일괄지급 내역 관리 API (일괄 지급 내역 다건 조회)
- 이체 내역 관련 API (이체 내역 다건 조회)

API 관련 상세 내용은 [개발 가이드 (링크) ](https://developers.portone.io/api/rest-v2/platform?v=v2)를 참고해 주세요.

### 서비스에 관심이 있으시다면?

문의를 남겨주시면 영업일 기준 2일 내로 담당자가 연락 드릴 예정입니다. \
언제든지 편히 문의 사항을 남겨주세요.

<Callout content="" title="서비스 문의 남기러 가기 ↗" />

###
